@@ -50,6 +50,11 @@ class CurrentData:
         """Last observation time (YYYY-MM-DD HH:MM)."""
         return self._ob_time
 
+    @property
+    def ts(self) -> float:
+        """Return UNIX Timestamp. (Local Time)"""
+        return self._ts
+
     @property
     def timestamp(self) -> str:
         """Date the forecast is valid for (YYYY-MM-DD HH:MM:SS)"""
@@ -126,7 +131,7 @@ class CurrentData:
         return self._weather_text
 
     @property
-    def vis(self) -> int:
+    def vis(self) -> float:
         """Visibility (default KM)."""
         return self._vis
 
@@ -179,24 +184,6 @@ class CurrentData:
         else:
             return False
 
-        # from_zone = tz.gettz("UTC")
-        # to_zone = tz.gettz(self.timezone)
-        # obs_time = datetime.strptime(self.ob_time, "%Y-%m-%d %H:%M")
-        # sun_rise = datetime.strptime(f"{obs_time.strftime('%Y-%m-%d')} {self.sunrise}", "%Y-%m-%d %H:%M")
-        # sun_set = datetime.strptime(f"{obs_time.strftime('%Y-%m-%d')} {self.sunset}", "%Y-%m-%d %H:%M")
-
-        # obs_day = obs_time.replace(tzinfo=from_zone)
-        # sun_rise = sun_rise.replace(tzinfo=from_zone)
-        # sun_set = sun_set.replace(tzinfo=from_zone)
-        # obs_local = obs_day.astimezone(to_zone)
-        # rise_local = sun_rise.astimezone(to_zone)
-        # set_local = sun_set.astimezone(to_zone)
-
-        # if obs_local >= set_local and obs_local <= rise_local:
-        #     return True
-        # else:
-        #     return False
-
     @property
     def obs_time_local(self) -> str:
         """Observation Time at Location."""
@@ -260,9 +247,9 @@ class ForecastDailyData:
 
     @property
     def ts(self) -> float:
-        """Return UNIX Timestamp."""
+        """Return UNIX Timestamp. (UTC)"""
         return self._ts
-        
+
     @property
     def ts_utc(self) -> dt:
         """Return datetime from Timestamp."""
@@ -387,6 +374,7 @@ class WeatherAlerts:
     """A representation of Severe Weather Alerts."""
 
     def __init__(self, data):
+        self._alert_count = data["alert_count"]
         self._city_name = data["city_name"]
         self._timezone = data["timezone"]
         self._title = data["title"]
@@ -397,6 +385,11 @@ class WeatherAlerts:
         self._uri = data["uri"]
         self._regions = data["regions"]
 
+    @property
+    def alert_count(self) -> int:
+        """Number of Weather Alerts."""
+        return self._alert_count
+
     @property
     def city_name(self) -> str:
         """Nearest city name."""
